package com.iotechn.unimall.admin.api.shop;


import com.iotechn.unimall.data.domain.shop.ShopLog;
import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.model.Page;
import java.util.Date;

/**
 * 同步日志Service接口
 * 
 * @author jlb
 * @date 2022-06-08
 */
@HttpOpenApi(group = "admin.shop.shopLog", description = "同步日志")
public interface IShopLogService{
	@HttpMethod(description = "新增", permission = "admin:shop:shopLog:add", permissionParentName = "同步日志", permissionName = "同步日志管理")
	public Boolean add(@NotNull @HttpParam(name = "shopLog", type = HttpParamType.COMMON, description = "同步日志") ShopLog shopLog,
						   @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "列表", permission = "admin:shop:shopLog:list",permissionParentName = "同步日志", permissionName = "同步日志管理")
	public Page<ShopLog> list(
								@HttpParam(name = "title", type = HttpParamType.COMMON, description = "标题") String title,
							@HttpParam(name = "content", type = HttpParamType.COMMON, description = "内容") String content,
										@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Long deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
					@HttpParam(name = "pageNum", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
		@HttpParam(name = "pageSize", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
		throws ServiceException;

	@HttpMethod(description = "删除", permission = "admin:shop:shopLog:delete",permissionParentName = "同步日志", permissionName = "同步日志管理")
	public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;

	@HttpMethod(description = "修改", permission = "admin:shopLog:shopLog:update",permissionParentName = "同步日志", permissionName = "同步日志管理")
	public Boolean update(@NotNull @HttpParam(name = "shopLog", type = HttpParamType.COMMON, description = "同步日志") ShopLog shopLog,
						  @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "查询", permission = "admin:shop:shopLog:get",permissionParentName = "同步日志", permissionName = "同步日志管理")
	public ShopLog get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;
	
	@HttpMethod(description = "导出excl表", permission = "admin:shop:shopLog:export",permissionParentName = "同步日志", permissionName = "同步日志管理")
	public String export(
								@HttpParam(name = "title", type = HttpParamType.COMMON, description = "标题") String title,
							@HttpParam(name = "content", type = HttpParamType.COMMON, description = "内容") String content,
										@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Long deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
				@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
	@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)throws ServiceException;
	
}
