package com.iotechn.unimall.admin.api.shop;


import com.iotechn.unimall.data.domain.shop.ShopTran;
import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.model.Page;
import java.util.Date;

/**
 * 物流公司Service接口
 * 
 * @author jlb
 * @date 2022-05-29
 */
@HttpOpenApi(group = "admin.shop.shopTran", description = "物流公司")
public interface IShopTranService{
	@HttpMethod(description = "新增", permission = "admin:shop:shopTran:add", permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public Boolean add(@NotNull @HttpParam(name = "shopTran", type = HttpParamType.COMMON, description = "物流公司") ShopTran shopTran,
						   @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "列表", permission = "admin:shop:shopTran:list",permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public Page<ShopTran> list(
								@HttpParam(name = "name", type = HttpParamType.COMMON, description = "物流公司名称") String name,
							@HttpParam(name = "code1", type = HttpParamType.COMMON, description = "物流公司编码") String code1,
							@HttpParam(name = "code2", type = HttpParamType.COMMON, description = "物流公司编码") String code2,
							@HttpParam(name = "phone", type = HttpParamType.COMMON, description = "物流公司电话") String phone,
										@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Integer deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
					@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
		@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
		throws ServiceException;

	@HttpMethod(description = "删除", permission = "admin:shop:shopTran:delete",permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;

	@HttpMethod(description = "修改", permission = "admin:shopTran:shopTran:update",permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public Boolean update(@NotNull @HttpParam(name = "shopTran", type = HttpParamType.COMMON, description = "物流公司") ShopTran shopTran,
						  @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "查询", permission = "admin:shop:shopTran:get",permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public ShopTran get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;
	
	@HttpMethod(description = "导出excl表", permission = "admin:shop:shopTran:export",permissionParentName = "宠物管理", permissionName = "物流公司管理")
	public String export(
								@HttpParam(name = "name", type = HttpParamType.COMMON, description = "物流公司名称") String name,
							@HttpParam(name = "code1", type = HttpParamType.COMMON, description = "物流公司编码") String code1,
							@HttpParam(name = "code2", type = HttpParamType.COMMON, description = "物流公司编码") String code2,
							@HttpParam(name = "phone", type = HttpParamType.COMMON, description = "物流公司电话") String phone,
										@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "删除标识") Integer deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
				@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
	@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)throws ServiceException;
	
}
